@@ -1,36 +1,36 @@
 /// Returns `true` if all clients of that version should have that mapres shipped with their client.
 pub fn is_external_name(name: &str) -> bool {
-    match name {
-        "bg_cloud1" | 
-        "bg_cloud2" | 
-        "bg_cloud3" | 
-        "desert_doodads" | 
-        "desert_main" | 
-        "desert_mountains" | 
-        "desert_mountains2" | 
-        "desert_sun" | 
-        "generic_deathtiles" | 
-        "generic_unhookable" | 
-        "grass_doodads" | 
-        "grass_main" | 
-        "jungle_background" | 
-        "jungle_deathtiles" | 
-        "jungle_doodads" | 
-        "jungle_main" | 
-        "jungle_midground" | 
-        "jungle_unhookables" | 
-        "moon" | 
-        "mountains" | 
-        "snow" | 
-        "stars" | 
-        "sun" | 
-        "winter_doodads" | 
-        "winter_main" | 
-        "winter_mountains" | 
-        "winter_mountains2" | 
-        "winter_mountains3" => true,
-        _ => false,
-    }
+    matches!(
+        name,
+        "bg_cloud1"
+            | "bg_cloud2"
+            | "bg_cloud3"
+            | "desert_doodads"
+            | "desert_main"
+            | "desert_mountains"
+            | "desert_mountains2"
+            | "desert_sun"
+            | "generic_deathtiles"
+            | "generic_unhookable"
+            | "grass_doodads"
+            | "grass_main"
+            | "jungle_background"
+            | "jungle_deathtiles"
+            | "jungle_doodads"
+            | "jungle_main"
+            | "jungle_midground"
+            | "jungle_unhookables"
+            | "moon"
+            | "mountains"
+            | "snow"
+            | "stars"
+            | "sun"
+            | "winter_doodads"
+            | "winter_main"
+            | "winter_mountains"
+            | "winter_mountains2"
+            | "winter_mountains3"
+    )
 }
 
 /// Returns the opaque table for external images.
@@ -55,9 +55,10 @@ pub fn external_opaque_table(name: &str) -> Option<[[bool; 16]; 16]> {
         "sun" => SUN,
         "winter_doodads" => WINTER_DOODADS,
         "winter_main" => WINTER_MAIN,
-        _ => return None
+        _ => return None,
     })
 }
+
 /// Returns the (width, height) of external images.
 /// None, if the given name is not a valid external image name.
 pub fn external_dimensions(name: &str) -> Option<(i32, i32)> {
@@ -90,10 +91,11 @@ pub fn external_dimensions(name: &str) -> Option<(i32, i32)> {
         "winter_mountains" => (1024, 512),
         "winter_mountains2" => (1024, 512),
         "winter_mountains3" => (1024, 512),
-        _ => return None
+        _ => return None,
     })
 }
 
+#[rustfmt::skip]
 const DESERT_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -113,6 +115,7 @@ const DESERT_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const DESERT_MAIN: [[bool; 16]; 16] = [
     [false,  true,  true,  true, false,  true,  true,  true, false, false, false, false, false, false, false, false],
     [ true, false,  true, false,  true,  true, false, false, false, false, false, false, false, false, false, false],
@@ -132,6 +135,7 @@ const DESERT_MAIN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const DESERT_SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -151,6 +155,7 @@ const DESERT_SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GENERIC_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -170,6 +175,7 @@ const GENERIC_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GENERIC_UNHOOKABLE: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -189,6 +195,7 @@ const GENERIC_UNHOOKABLE: [[bool; 16]; 16] = [
     [false,  true, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GRASS_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false,  true, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -208,6 +215,7 @@ const GRASS_DOODADS: [[bool; 16]; 16] = [
     [false, false,  true, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GRASS_MAIN: [[bool; 16]; 16] = [
     [false,  true,  true,  true, false, false, false, false, false, false, false,  true,  true,  true, false, false],
     [ true,  true,  true,  true, false, false, false, false, false, false, false,  true,  true,  true, false, false],
@@ -227,6 +235,7 @@ const GRASS_MAIN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -246,6 +255,7 @@ const JUNGLE_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -265,6 +275,7 @@ const JUNGLE_DOODADS: [[bool; 16]; 16] = [
     [false, false,  true,  true, false, false, false, false,  true,  true, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_MAIN: [[bool; 16]; 16] = [
     [false,  true,  true,  true, false, false, false, false, false, false, false, false, false,  true, false, false],
     [ true,  true,  true,  true, false, false, false, false, false, false, false, false, false,  true, false, false],
@@ -284,6 +295,7 @@ const JUNGLE_MAIN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_MIDGROUND: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false,  true, false, false, false, false, false, false, false, false, false, false],
@@ -303,6 +315,7 @@ const JUNGLE_MIDGROUND: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_UNHOOKABLES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -322,6 +335,7 @@ const JUNGLE_UNHOOKABLES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const MOON: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -341,6 +355,7 @@ const MOON: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const SNOW: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -360,6 +375,7 @@ const SNOW: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -379,6 +395,7 @@ const SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const WINTER_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false,  true, false, false, false, false, false,  true, false, false],
@@ -398,6 +415,7 @@ const WINTER_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false,  true,  true,  true, false, false, false],
 ];
 
+#[rustfmt::skip]
 const WINTER_MAIN: [[bool; 16]; 16] = [
     [false,  true, false,  true,  true, false, false, false, false,  true,  true,  true,  true,  true,  true,  true],
     [false,  true,  true,  true, false, false,  true,  true, false,  true,  true,  true,  true,  true,  true,  true],
