@@ -1,40 +1,40 @@
 /// Returns `true` if all clients of that version should have that mapres shipped with their client.
 pub fn is_external_name(name: &str) -> bool {
-    match name {
-        "bg_cloud1" | 
-        "bg_cloud2" | 
-        "bg_cloud3" | 
-        "desert_doodads" | 
-        "desert_main" | 
-        "desert_mountains" | 
-        "desert_mountains2" | 
-        "desert_sun" | 
-        "easter" | 
-        "generic_deathtiles" | 
-        "generic_lamps" | 
-        "generic_shadows" | 
-        "generic_unhookable" | 
-        "grass_doodads" | 
-        "grass_main" | 
-        "jungle_background" | 
-        "jungle_deathtiles" | 
-        "jungle_doodads" | 
-        "jungle_main" | 
-        "jungle_midground" | 
-        "jungle_unhookables" | 
-        "light" | 
-        "moon" | 
-        "mountains" | 
-        "snow" | 
-        "stars" | 
-        "sun" | 
-        "winter_doodads" | 
-        "winter_main" | 
-        "winter_mountains" | 
-        "winter_mountains2" | 
-        "winter_mountains3" => true,
-        _ => false,
-    }
+    matches!(
+        name,
+        "bg_cloud1"
+            | "bg_cloud2"
+            | "bg_cloud3"
+            | "desert_doodads"
+            | "desert_main"
+            | "desert_mountains"
+            | "desert_mountains2"
+            | "desert_sun"
+            | "easter"
+            | "generic_deathtiles"
+            | "generic_lamps"
+            | "generic_shadows"
+            | "generic_unhookable"
+            | "grass_doodads"
+            | "grass_main"
+            | "jungle_background"
+            | "jungle_deathtiles"
+            | "jungle_doodads"
+            | "jungle_main"
+            | "jungle_midground"
+            | "jungle_unhookables"
+            | "light"
+            | "moon"
+            | "mountains"
+            | "snow"
+            | "stars"
+            | "sun"
+            | "winter_doodads"
+            | "winter_main"
+            | "winter_mountains"
+            | "winter_mountains2"
+            | "winter_mountains3"
+    )
 }
 
 /// Returns the opaque table for external images.
@@ -63,9 +63,10 @@ pub fn external_opaque_table(name: &str) -> Option<[[bool; 16]; 16]> {
         "sun" => SUN,
         "winter_doodads" => WINTER_DOODADS,
         "winter_main" => WINTER_MAIN,
-        _ => return None
+        _ => return None,
     })
 }
+
 /// Returns the (width, height) of external images.
 /// None, if the given name is not a valid external image name.
 pub fn external_dimensions(name: &str) -> Option<(i32, i32)> {
@@ -102,10 +103,11 @@ pub fn external_dimensions(name: &str) -> Option<(i32, i32)> {
         "winter_mountains" => (1024, 512),
         "winter_mountains2" => (1024, 512),
         "winter_mountains3" => (1024, 512),
-        _ => return None
+        _ => return None,
     })
 }
 
+#[rustfmt::skip]
 const DESERT_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -125,6 +127,7 @@ const DESERT_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const DESERT_MAIN: [[bool; 16]; 16] = [
     [false,  true,  true,  true, false,  true,  true,  true, false, false,  true,  true, false, false,  true, false],
     [ true, false,  true, false,  true,  true, false, false, false, false, false, false, false, false, false, false],
@@ -144,6 +147,7 @@ const DESERT_MAIN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const DESERT_SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -163,6 +167,7 @@ const DESERT_SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const EASTER: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -182,6 +187,7 @@ const EASTER: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GENERIC_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -201,6 +207,7 @@ const GENERIC_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GENERIC_LAMPS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -220,6 +227,7 @@ const GENERIC_LAMPS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GENERIC_SHADOWS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -239,6 +247,7 @@ const GENERIC_SHADOWS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GENERIC_UNHOOKABLE: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -258,6 +267,7 @@ const GENERIC_UNHOOKABLE: [[bool; 16]; 16] = [
     [false,  true, false, false,  true, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GRASS_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -277,6 +287,7 @@ const GRASS_DOODADS: [[bool; 16]; 16] = [
     [false, false,  true, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const GRASS_MAIN: [[bool; 16]; 16] = [
     [false,  true,  true,  true, false, false, false, false, false, false, false,  true,  true,  true,  true,  true],
     [ true,  true,  true,  true, false, false, false, false, false, false, false,  true,  true,  true,  true,  true],
@@ -296,6 +307,7 @@ const GRASS_MAIN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -315,6 +327,7 @@ const JUNGLE_DEATHTILES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -334,6 +347,7 @@ const JUNGLE_DOODADS: [[bool; 16]; 16] = [
     [false, false,  true,  true, false, false, false, false,  true,  true, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_MAIN: [[bool; 16]; 16] = [
     [false,  true,  true,  true, false, false, false, false, false, false, false, false, false,  true, false, false],
     [ true,  true,  true,  true, false, false, false, false, false, false, false, false, false,  true, false, false],
@@ -353,6 +367,7 @@ const JUNGLE_MAIN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_MIDGROUND: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false,  true, false, false, false, false, false, false, false, false, false, false],
@@ -372,6 +387,7 @@ const JUNGLE_MIDGROUND: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const JUNGLE_UNHOOKABLES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -391,6 +407,7 @@ const JUNGLE_UNHOOKABLES: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const LIGHT: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -410,6 +427,7 @@ const LIGHT: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const MOON: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -429,6 +447,7 @@ const MOON: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const SNOW: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -448,6 +467,7 @@ const SNOW: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
@@ -467,6 +487,7 @@ const SUN: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
 ];
 
+#[rustfmt::skip]
 const WINTER_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false],
     [false, false, false, false, false, false, false,  true, false, false, false, false, false,  true, false, false],
@@ -486,6 +507,7 @@ const WINTER_DOODADS: [[bool; 16]; 16] = [
     [false, false, false, false, false, false, false, false, false, false,  true,  true,  true, false, false, false],
 ];
 
+#[rustfmt::skip]
 const WINTER_MAIN: [[bool; 16]; 16] = [
     [false,  true, false,  true,  true, false, false, false, false,  true,  true,  true,  true,  true,  true,  true],
     [false,  true,  true,  true, false, false,  true,  true, false,  true,  true,  true,  true,  true,  true,  true],
