@@ -3,7 +3,9 @@ use std::fmt;
 
 pub trait To {
     fn to<T>(self) -> T
-    where Self: Into<T> + Sized {
+    where
+        Self: Into<T> + Sized,
+    {
         self.into()
     }
 }
@@ -12,10 +14,12 @@ impl<T> To for T {}
 
 pub trait TryTo {
     fn try_to<T>(self) -> T
-        where Self: TryInto<T> + Sized,
-        <Self as TryInto<T>>::Error: fmt::Debug {
+    where
+        Self: TryInto<T> + Sized,
+        <Self as TryInto<T>>::Error: fmt::Debug,
+    {
         self.try_into().unwrap()
     }
 }
 
-impl<T> TryTo for T {}
\ No newline at end of file
+impl<T> TryTo for T {}
