@@ -1,18 +1,18 @@
-use crate::map::*;
 use crate::convert::TryTo;
+use crate::map::*;
 
 use image::ImageError;
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 use thiserror::Error;
 
 use std::cell::RefCell;
 use std::collections::HashMap;
 use std::convert::TryFrom;
-use std::io;
-use std::io::Write;
 use std::ffi::OsString;
 use std::fmt;
 use std::fs;
+use std::io;
+use std::io::Write;
 use std::path::{Path, PathBuf};
 
 thread_local! {
@@ -27,7 +27,7 @@ thread_local! {
 
 fn save_json_file<T: Serialize>(json: &T, path: &Path) -> io::Result<()> {
     let mut bytes = serde_json::to_vec_pretty(json).unwrap();
-    bytes.push('\n' as u8);
+    bytes.push(b'\n');
     save_bin_file(&bytes, path, "json")
 }
 
@@ -60,9 +60,14 @@ impl fmt::Display for MapDirError {
         write!(f, "{:?}: ", self.path)?;
         match &self.kind {
             InvalidUtf8 => write!(f, "Invalid utf-8 in file name"),
-            PhysicsLayerName(variant) => write!(f, "Physics layer '{:?}' has an incorrect name", variant),
+            PhysicsLayerName(variant) => {
+                write!(f, "Physics layer '{:?}' has an incorrect name", variant)
+            }
             ColorDepth16 => write!(f, "Images with 16 bits per channel are not supported"),
-            DuplicateImageName => write!(f, "Two images have the same file name with different extensions (.png, .json)"),
+            DuplicateImageName => write!(
+                f,
+                "Two images have the same file name with different extensions (.png, .json)"
+            ),
             Io(err) => write!(f, "{}", err),
             Json(err) => write!(f, "{}", err),
             Image(err) => write!(f, "{}", err),
@@ -84,7 +89,7 @@ impl<T> WithPath for Result<T, MapDirErrorKind> {
             Err(kind) => Err(MapDirError {
                 kind,
                 path: path.into(),
-            })
+            }),
         }
     }
 }
@@ -97,7 +102,7 @@ impl<T> WithPath for io::Result<T> {
             Err(err) => Err(MapDirError {
                 kind: MapDirErrorKind::Io(err),
                 path: path.into(),
-            })
+            }),
         }
     }
 }
@@ -110,7 +115,7 @@ impl<T> WithPath for Result<T, serde_json::Error> {
             Err(err) => Err(MapDirError {
                 kind: MapDirErrorKind::Json(err),
                 path: path.into(),
-            })
+            }),
         }
     }
 }
@@ -123,7 +128,7 @@ impl<T> WithPath for Result<T, ImageError> {
             Err(err) => Err(MapDirError {
                 kind: MapDirErrorKind::Image(err),
                 path: path.into(),
-            })
+            }),
         }
     }
 }
@@ -140,20 +145,35 @@ impl TwMap {
 
     fn save_dir_unwrap<P: AsRef<Path>>(&mut self, path: P) -> io::Result<()> {
         let path = path.as_ref();
-        IMAGE_NAMES.with(|f| *f.borrow_mut() = Some(self.images.iter()
-            .enumerate()
-            .map(|(index, image)| indexed_name(image.name(), index, self.images.len()))
-            .collect()));
+        IMAGE_NAMES.with(|f| {
+            *f.borrow_mut() = Some(
+                self.images
+                    .iter()
+                    .enumerate()
+                    .map(|(index, image)| indexed_name(image.name(), index, self.images.len()))
+                    .collect(),
+            )
+        });
 
-        ENVELOPE_NAMES.with(|f| *f.borrow_mut() = Some(self.envelopes.iter()
-            .enumerate()
-            .map(|(index, env)| indexed_name(env.name(), index, self.envelopes.len()))
-            .collect()));
+        ENVELOPE_NAMES.with(|f| {
+            *f.borrow_mut() = Some(
+                self.envelopes
+                    .iter()
+                    .enumerate()
+                    .map(|(index, env)| indexed_name(env.name(), index, self.envelopes.len()))
+                    .collect(),
+            )
+        });
 
-        SOUND_NAMES.with(|f| *f.borrow_mut() = Some(self.sounds.iter()
-            .enumerate()
-            .map(|(index, env)| indexed_name(&env.name, index, self.sounds.len()))
-            .collect()));
+        SOUND_NAMES.with(|f| {
+            *f.borrow_mut() = Some(
+                self.sounds
+                    .iter()
+                    .enumerate()
+                    .map(|(index, env)| indexed_name(&env.name, index, self.sounds.len()))
+                    .collect(),
+            )
+        });
 
         fs::create_dir(path)?;
 
@@ -162,7 +182,7 @@ impl TwMap {
         let dir_version = DirVersion::from(self.version);
         save_json_file(&dir_version, &path.join("version"))?;
 
-        if self.images.len() != 0 {
+        if !self.images.is_empty() {
             let images_path = path.join("images");
             fs::create_dir(&images_path)?;
 
@@ -173,11 +193,11 @@ impl TwMap {
             }
         }
 
-        if self.envelopes.len() != 0 {
+        if !self.envelopes.is_empty() {
             let envelopes_path = path.join("envelopes");
             fs::create_dir(&envelopes_path)?;
             for (i, envelope) in self.envelopes.iter().enumerate() {
-                let envelope_file_name = indexed_name(&envelope.name(), i, self.envelopes.len());
+                let envelope_file_name = indexed_name(envelope.name(), i, self.envelopes.len());
                 let envelope_path = envelopes_path.join(&envelope_file_name);
                 save_json_file(&envelope, &envelope_path)?;
             }
@@ -196,13 +216,13 @@ impl TwMap {
                 fs::create_dir(&group_layers_path)?;
             }
             for (i, layer) in group.layers.iter().enumerate() {
-                let layer_file_name = indexed_name(&layer.name(), i, group.layers.len());
+                let layer_file_name = indexed_name(layer.name(), i, group.layers.len());
                 let layer_path = group_layers_path.join(layer_file_name);
                 save_json_file(&layer, &layer_path)?;
             }
         }
 
-        if self.sounds.len() != 0 {
+        if !self.sounds.is_empty() {
             let sounds_path = path.join("sounds");
             fs::create_dir(&sounds_path)?;
             for (i, sound) in self.sounds.iter().enumerate() {
@@ -235,16 +255,13 @@ impl TwMap {
         let sounds_path = path.join("sounds");
 
         let image_names_mapping = create_dir_mapping(&images_path, &["png", "json"])?;
-        IMAGE_NAMES_MAPPING.with(|f|
-            *f.borrow_mut() = Some(image_names_mapping));
+        IMAGE_NAMES_MAPPING.with(|f| *f.borrow_mut() = Some(image_names_mapping));
 
         let envelope_names_mapping = create_dir_mapping(&envelopes_path, &["json"])?;
-        ENVELOPE_NAMES_MAPPING.with(|f|
-            *f.borrow_mut() = Some(envelope_names_mapping));
+        ENVELOPE_NAMES_MAPPING.with(|f| *f.borrow_mut() = Some(envelope_names_mapping));
 
         let sound_names_mapping = create_dir_mapping(&sounds_path, &["opus"])?;
-        SOUND_NAMES_MAPPING.with(|f|
-            *f.borrow_mut() = Some(sound_names_mapping));
+        SOUND_NAMES_MAPPING.with(|f| *f.borrow_mut() = Some(sound_names_mapping));
 
         let info_path = path.join("info.json");
         let info = Info::deserialize_json(&info_path)?;
@@ -289,8 +306,7 @@ impl TwMap {
         let mut sounds = Vec::new();
         for sound_name in list_dir(&sounds_path, &["opus"])? {
             let sound_path = sounds_path.join(&sound_name);
-            let data = fs::read(&sound_path)
-                .err_with_path(&sound_path)?;
+            let data = fs::read(&sound_path).err_with_path(&sound_path)?;
             sounds.push(Sound {
                 name: strip_name(sound_name),
                 data: CompressedData::Loaded(data),
@@ -310,23 +326,28 @@ impl TwMap {
 
 trait DeserializeJson: for<'de> Deserialize<'de> {
     fn deserialize_json(path: &Path) -> Result<Self, MapDirError> {
-        let file = fs::read(path)
-            .err_with_path(&path)?;
-        serde_json::from_slice(&file)
-            .err_with_path(&path)
+        let file = fs::read(path).err_with_path(&path)?;
+        serde_json::from_slice(&file).err_with_path(&path)
     }
 }
 
 impl<T: for<'de> Deserialize<'de>> DeserializeJson for T {}
 
-fn create_dir_mapping(path: &Path, extensions: &[&str]) -> Result<HashMap<String, u16>, MapDirError> {
+fn create_dir_mapping(
+    path: &Path,
+    extensions: &[&str],
+) -> Result<HashMap<String, u16>, MapDirError> {
     let file_names = list_dir(path, extensions)?;
     let mut file_mapping = HashMap::new();
     for (i, file_name) in file_names.iter().enumerate() {
-        let name = PathBuf::from(&file_name).file_stem().unwrap().to_str().unwrap().to_string();
+        let name = PathBuf::from(&file_name)
+            .file_stem()
+            .unwrap()
+            .to_str()
+            .unwrap()
+            .to_string();
         if file_mapping.contains_key(&name) {
-            return Err(MapDirErrorKind::DuplicateImageName)
-                .err_with_path(path.join(&name))?;
+            return Err(MapDirErrorKind::DuplicateImageName).err_with_path(path.join(&name))?;
         }
         file_mapping.insert(name, i.try_to::<u16>());
     }
@@ -334,9 +355,7 @@ fn create_dir_mapping(path: &Path, extensions: &[&str]) -> Result<HashMap<String
 }
 
 fn list_dir(path: &Path, extensions: &[&str]) -> Result<Vec<String>, MapDirError> {
-    let extensions: Vec<OsString> = extensions.iter()
-        .map(|str| OsString::from(str))
-        .collect();
+    let extensions: Vec<OsString> = extensions.iter().map(OsString::from).collect();
 
     // filter out file names with incorrect extension
     let dir_entries = match fs::read_dir(path) {
@@ -344,8 +363,7 @@ fn list_dir(path: &Path, extensions: &[&str]) -> Result<Vec<String>, MapDirError
         Err(err) => {
             return if err.kind() == io::ErrorKind::NotFound {
                 Ok(Vec::new())
-            }
-            else {
+            } else {
                 Err(err).err_with_path(path)
             }
         }
@@ -360,17 +378,14 @@ fn list_dir(path: &Path, extensions: &[&str]) -> Result<Vec<String>, MapDirError
                 if let Some(ext) = PathBuf::from(&file_name).extension() {
                     if extensions.contains(&ext.to_os_string()) {
                         Some(Ok(file_name))
-                    }
-                    else {
+                    } else {
                         None
                     }
-                }
-                else {
+                } else {
                     // no extensions is used for listing directories
                     if extensions.is_empty() {
                         Some(Ok(file_name))
-                    }
-                    else {
+                    } else {
                         None
                     }
                 }
@@ -379,7 +394,8 @@ fn list_dir(path: &Path, extensions: &[&str]) -> Result<Vec<String>, MapDirError
         .collect::<Result<Vec<_>, MapDirError>>()?;
 
     // ensure proper utf-8
-    let mut file_names = file_names.into_iter()
+    let mut file_names = file_names
+        .into_iter()
         .map(|os_str| match os_str.to_str() {
             None => Err(MapDirErrorKind::InvalidUtf8).err_with_path(path.join(os_str)),
             Some(str) => Ok(str.to_string()),
@@ -398,13 +414,11 @@ fn with_extension(path: &Path, extension: &str) -> PathBuf {
     PathBuf::from(path)
 }
 
-
 fn indexed_name(name: &str, i: usize, length: usize) -> String {
     let pad_length = (length - 1).to_string().chars().count();
     if name.is_empty() {
         format!("{:0width$}", i, width = pad_length)
-    }
-    else {
+    } else {
         format!("{:0width$}_{}", i, sanitize_name(name), width = pad_length)
     }
 }
@@ -412,17 +426,21 @@ fn indexed_name(name: &str, i: usize, length: usize) -> String {
 // removes index + file extension
 fn strip_name(mut name: String) -> String {
     // remove file extension
-    name = PathBuf::from(name).file_stem().unwrap().to_str().unwrap().to_string();
+    name = PathBuf::from(name)
+        .file_stem()
+        .unwrap()
+        .to_str()
+        .unwrap()
+        .to_string();
 
     // remove prefixed index, if it exists
-    if let Some(mid) = name.find("_") {
+    if let Some(mid) = name.find('_') {
         let (prefix, remaining) = name.split_at(mid + 1);
         match prefix[..prefix.len() - 1].parse::<usize>() {
             Ok(_) => remaining.to_string(),
             Err(_) => name,
         }
-    }
-    else {
+    } else {
         match name.parse::<usize>() {
             Ok(_) => String::new(),
             Err(_) => name,
@@ -431,11 +449,14 @@ fn strip_name(mut name: String) -> String {
 }
 
 fn sanitize_name(name: &str) -> String {
-    sanitize_filename::sanitize_with_options(name, sanitize_filename::Options {
-        windows: true,
-        truncate: true,
-        replacement: "_"
-    })
+    sanitize_filename::sanitize_with_options(
+        name,
+        sanitize_filename::Options {
+            windows: true,
+            truncate: true,
+            replacement: "_",
+        },
+    )
 }
 
 #[derive(Serialize, Deserialize)]
@@ -463,7 +484,8 @@ impl Image {
             Image::External(img) => save_json_file(&img, path)?,
             Image::Embedded(img) => {
                 let image = img.image.unwrap_ref();
-                image.save(with_extension(path,"png"))
+                image
+                    .save(with_extension(path, "png"))
                     .map_err(|err| match err {
                         ImageError::IoError(err) => err,
                         _ => panic!("Image saving error that shouldn't happen."),
@@ -478,8 +500,7 @@ impl Image {
     fn from_file(path: &Path) -> Result<Self, MapDirError> {
         match path.extension().unwrap().to_str().unwrap() {
             "json" => Ok(ExternalImage::deserialize_json(path)?.into()),
-            "png" => Ok(EmbeddedImage::from_file(path)
-                .err_with_path(path)?.into()),
+            "png" => Ok(EmbeddedImage::from_file(path).err_with_path(path)?.into()),
             _ => unreachable!(),
         }
     }
@@ -513,7 +534,10 @@ pub struct DirTileFlagsError(i32);
 
 impl fmt::Display for DirTileFlagsError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "rotation can only be one of the values 0, 90, 180 and 270")
+        write!(
+            f,
+            "rotation can only be one of the values 0, 90, 180 and 270"
+        )
     }
 }
 
@@ -523,7 +547,7 @@ impl TryFrom<DirTileFlags> for TileFlags {
     fn try_from(v: DirTileFlags) -> Result<Self, Self::Error> {
         let mut flags = TileFlags::empty();
         match v.rotation {
-            0 => {},
+            0 => {}
             90 => flags.insert(TileFlags::ROTATE),
             180 => flags.insert(TileFlags::FLIP_H),
             270 => flags.insert(TileFlags::FLIP_H | TileFlags::ROTATE),
@@ -537,11 +561,11 @@ impl TryFrom<DirTileFlags> for TileFlags {
 }
 
 pub(crate) mod tiles_serialization {
-    use crate::map::*;
-    use serde::{Serialize, Serializer, Deserialize, Deserializer};
-    use ndarray::Array2;
-    use std::fmt;
     use crate::convert::TryTo;
+    use crate::map::*;
+    use ndarray::Array2;
+    use serde::{Deserialize, Deserializer, Serialize, Serializer};
+    use std::fmt;
 
     #[derive(Serialize, Deserialize)]
     struct DirTile<T> {
@@ -558,18 +582,23 @@ pub(crate) mod tiles_serialization {
         tiles: Vec<DirTile<T>>,
     }
 
-    fn dir_tiles<T>(tiles: &Array2<T>) -> DirTiles<T> where
-        T: Serialize + Default + PartialEq + Copy {
+    fn dir_tiles<T>(tiles: &Array2<T>) -> DirTiles<T>
+    where
+        T: Serialize + Default + PartialEq + Copy,
+    {
         let width = tiles.ncols();
         let height = tiles.nrows();
 
-        let tiles = tiles.indexed_iter()
+        let tiles = tiles
+            .indexed_iter()
             .filter_map(|((y, x), tile)| {
                 if *tile == T::default() {
                     None
-                }
-                else {
-                    let pos = Point { x: (x.try_to()), y: y.try_to() };
+                } else {
+                    let pos = Point {
+                        x: (x.try_to()),
+                        y: y.try_to(),
+                    };
                     let tile = *tile;
                     let dir_tile = DirTile { pos, tile };
                     Some(dir_tile)
@@ -584,9 +613,14 @@ pub(crate) mod tiles_serialization {
         }
     }
 
-    pub(crate) fn serialize<T, S>(tiles: &CompressedData<Array2<T>, TilesLoadInfo>, serializer: S) -> Result<S::Ok, S::Error> where
+    pub(crate) fn serialize<T, S>(
+        tiles: &CompressedData<Array2<T>, TilesLoadInfo>,
+        serializer: S,
+    ) -> Result<S::Ok, S::Error>
+    where
         T: Serialize + Default + PartialEq + Copy,
-        S: Serializer {
+        S: Serializer,
+    {
         let tiles = tiles.unwrap_ref();
         dir_tiles(tiles).serialize(serializer)
     }
@@ -606,49 +640,61 @@ pub(crate) mod tiles_serialization {
         }
     }
 
-    fn undir_tiles<'a, T>(dir_tiles: DirTiles<T>) -> Result<Array2<T>, DirTileError> where
-        T: Deserialize<'a> + Default + PartialEq + Copy {
+    fn undir_tiles<'a, T>(dir_tiles: DirTiles<T>) -> Result<Array2<T>, DirTileError>
+    where
+        T: Deserialize<'a> + Default + PartialEq + Copy,
+    {
         use DirTileError::*;
 
         let shape = (dir_tiles.height, dir_tiles.width);
         let mut tiles: Array2<Option<T>> = Array2::default(shape);
 
         for dir_tile in dir_tiles.tiles {
-            let pos = (dir_tile.pos.y.try_to::<usize>(), dir_tile.pos.x.try_to::<usize>());
+            let pos = (
+                dir_tile.pos.y.try_to::<usize>(),
+                dir_tile.pos.x.try_to::<usize>(),
+            );
             match tiles.get(pos) {
                 None => return Err(OutOfBounds(pos, shape)),
                 Some(Some(_)) => return Err(DuplicateTile(pos)),
                 Some(None) => tiles[pos] = Some(dir_tile.tile),
             }
         }
-        let tiles = tiles.map(|&t| {
-            match t {
-                None => T::default(),
-                Some(t) => t,
-            }
+        let tiles = tiles.map(|&t| match t {
+            None => T::default(),
+            Some(t) => t,
         });
         Ok(tiles)
     }
 
-    pub(crate) fn deserialize<'de, T, D>(deserializer: D) -> Result<CompressedData<Array2<T>, TilesLoadInfo>, D::Error> where
+    pub(crate) fn deserialize<'de, T, D>(
+        deserializer: D,
+    ) -> Result<CompressedData<Array2<T>, TilesLoadInfo>, D::Error>
+    where
         T: Deserialize<'de> + Default + PartialEq + Copy,
-        D: Deserializer<'de> {
+        D: Deserializer<'de>,
+    {
         let tiles = DirTiles::deserialize(deserializer)?;
-        let tiles = undir_tiles(tiles)
-            .map_err(|err| serde::de::Error::custom(err))?;
+        let tiles = undir_tiles(tiles).map_err(serde::de::Error::custom)?;
         Ok(CompressedData::Loaded(tiles))
     }
 }
 
 pub(crate) mod image_index_serialization {
-    use serde::{Serialize, Serializer, Deserializer, Deserialize};
     use super::{IMAGE_NAMES, IMAGE_NAMES_MAPPING};
-    use std::fmt;
     use crate::convert::To;
+    use serde::{Deserialize, Deserializer, Serialize, Serializer};
+    use std::fmt;
 
-    pub(crate) fn serialize<S: Serializer>(opt_index: &Option<u16>, serializer: S) -> Result<S::Ok, S::Error> {
-        IMAGE_NAMES.with(|f| opt_index.map(|index|
-            f.borrow().as_ref().unwrap()[index.to::<usize>()].clone()).serialize(serializer))
+    pub(crate) fn serialize<S: Serializer>(
+        opt_index: &Option<u16>,
+        serializer: S,
+    ) -> Result<S::Ok, S::Error> {
+        IMAGE_NAMES.with(|f| {
+            opt_index
+                .map(|index| f.borrow().as_ref().unwrap()[index.to::<usize>()].clone())
+                .serialize(serializer)
+        })
     }
 
     struct ImageNameMissing(String);
@@ -659,29 +705,38 @@ pub(crate) mod image_index_serialization {
         }
     }
 
-    pub(crate) fn deserialize<'de, D: Deserializer<'de>>(deserializer: D) -> Result<Option<u16>, D::Error> {
+    pub(crate) fn deserialize<'de, D: Deserializer<'de>>(
+        deserializer: D,
+    ) -> Result<Option<u16>, D::Error> {
         let opt_name = <Option<String>>::deserialize(deserializer)?;
         let opt_index = match opt_name {
             None => None,
-            Some(name) => IMAGE_NAMES_MAPPING.with(|f|
-                match f.borrow().as_ref().unwrap().get(&name) {
+            Some(name) => {
+                IMAGE_NAMES_MAPPING.with(|f| match f.borrow().as_ref().unwrap().get(&name) {
                     None => Err(serde::de::Error::custom(ImageNameMissing(name))),
-                    Some(&index) => Ok(Some(index))
+                    Some(&index) => Ok(Some(index)),
                 })?
+            }
         };
         Ok(opt_index)
     }
 }
 
 pub(crate) mod sound_index_serialization {
-    use crate::convert::To;
-    use serde::{Serialize, Serializer, Deserializer, Deserialize};
     use super::{SOUND_NAMES, SOUND_NAMES_MAPPING};
+    use crate::convert::To;
+    use serde::{Deserialize, Deserializer, Serialize, Serializer};
     use std::fmt;
 
-    pub(crate) fn serialize<S: Serializer>(opt_index: &Option<u16>, serializer: S) -> Result<S::Ok, S::Error> {
-        SOUND_NAMES.with(|f| opt_index.map(|index|
-            f.borrow().as_ref().unwrap()[index.to::<usize>()].clone()).serialize(serializer))
+    pub(crate) fn serialize<S: Serializer>(
+        opt_index: &Option<u16>,
+        serializer: S,
+    ) -> Result<S::Ok, S::Error> {
+        SOUND_NAMES.with(|f| {
+            opt_index
+                .map(|index| f.borrow().as_ref().unwrap()[index.to::<usize>()].clone())
+                .serialize(serializer)
+        })
     }
 
     struct SoundNameMissing(String);
@@ -692,29 +747,38 @@ pub(crate) mod sound_index_serialization {
         }
     }
 
-    pub(crate) fn deserialize<'de, D: Deserializer<'de>>(deserializer: D) -> Result<Option<u16>, D::Error> {
+    pub(crate) fn deserialize<'de, D: Deserializer<'de>>(
+        deserializer: D,
+    ) -> Result<Option<u16>, D::Error> {
         let opt_name = <Option<String>>::deserialize(deserializer)?;
         let opt_index = match opt_name {
             None => None,
-            Some(name) => SOUND_NAMES_MAPPING.with(|f|
-                match f.borrow().as_ref().unwrap().get(&name) {
+            Some(name) => {
+                SOUND_NAMES_MAPPING.with(|f| match f.borrow().as_ref().unwrap().get(&name) {
                     None => Err(serde::de::Error::custom(SoundNameMissing(name))),
-                    Some(&index) => Ok(Some(index))
+                    Some(&index) => Ok(Some(index)),
                 })?
+            }
         };
         Ok(opt_index)
     }
 }
 
 pub(crate) mod envelope_index_serialization {
-    use crate::convert::To;
-    use serde::{Serialize, Serializer, Deserializer, Deserialize};
     use super::{ENVELOPE_NAMES, ENVELOPE_NAMES_MAPPING};
+    use crate::convert::To;
+    use serde::{Deserialize, Deserializer, Serialize, Serializer};
     use std::fmt;
 
-    pub(crate) fn serialize<S: Serializer>(opt_index: &Option<u16>, serializer: S) -> Result<S::Ok, S::Error> {
-        ENVELOPE_NAMES.with(|f| opt_index.map(|index|
-            f.borrow().as_ref().unwrap()[index.to::<usize>()].clone()).serialize(serializer))
+    pub(crate) fn serialize<S: Serializer>(
+        opt_index: &Option<u16>,
+        serializer: S,
+    ) -> Result<S::Ok, S::Error> {
+        ENVELOPE_NAMES.with(|f| {
+            opt_index
+                .map(|index| f.borrow().as_ref().unwrap()[index.to::<usize>()].clone())
+                .serialize(serializer)
+        })
     }
 
     struct EnvelopeNameMissing(String);
@@ -725,15 +789,18 @@ pub(crate) mod envelope_index_serialization {
         }
     }
 
-    pub(crate) fn deserialize<'de, D: Deserializer<'de>>(deserializer: D) -> Result<Option<u16>, D::Error> {
+    pub(crate) fn deserialize<'de, D: Deserializer<'de>>(
+        deserializer: D,
+    ) -> Result<Option<u16>, D::Error> {
         let opt_name = <Option<String>>::deserialize(deserializer)?;
         let opt_index = match opt_name {
             None => None,
-            Some(name) => ENVELOPE_NAMES_MAPPING.with(|f|
-                match f.borrow().as_ref().unwrap().get(&name) {
+            Some(name) => {
+                ENVELOPE_NAMES_MAPPING.with(|f| match f.borrow().as_ref().unwrap().get(&name) {
                     None => Err(serde::de::Error::custom(EnvelopeNameMissing(name))),
-                    Some(&index) => Ok(Some(index))
+                    Some(&index) => Ok(Some(index)),
                 })?
+            }
         };
         Ok(opt_index)
     }
