@@ -1,5 +1,5 @@
-use crate::map::*;
 use crate::convert::TryTo;
+use crate::map::*;
 
 use image::RgbaImage;
 use ndarray::Array2;
@@ -49,14 +49,16 @@ impl TwMap {
 
     /// Returns a reference to the physics group.
     pub fn physics_group(&self) -> &Group {
-        self.groups.iter()
+        self.groups
+            .iter()
             .find(|group| group.is_physics_group())
             .unwrap()
     }
 
     /// Returns a mutable reference to the physics group.
     pub fn physics_group_mut(&mut self) -> &mut Group {
-        self.groups.iter_mut()
+        self.groups
+            .iter_mut()
             .find(|group| group.is_physics_group())
             .unwrap()
     }
@@ -71,7 +73,8 @@ impl fmt::Display for Point {
 impl Group {
     /// Checks if the group contains any physics layers.
     pub fn is_physics_group(&self) -> bool {
-        self.layers.iter()
+        self.layers
+            .iter()
             .any(|layer| layer.kind().is_physics_layer())
     }
 }
@@ -89,7 +92,7 @@ impl From<EmbeddedImage> for Image {
 }
 
 impl Image {
-    pub fn name(&self) -> &String {
+    pub const fn name(&self) -> &String {
         match self {
             Image::External(img) => &img.name,
             Image::Embedded(img) => &img.name,
@@ -123,23 +126,23 @@ impl Image {
         }
     }
 
-    pub fn image(&self) -> Option<&CompressedData<RgbaImage, ImageLoadInfo>> {
+    pub const fn image(&self) -> Option<&CompressedData<RgbaImage, ImageLoadInfo>> {
         match self {
             Image::External(_) => None,
-            Image::Embedded(image) => Some(&image.image)
+            Image::Embedded(image) => Some(&image.image),
         }
     }
 
     pub fn image_mut(&mut self) -> Option<&mut CompressedData<RgbaImage, ImageLoadInfo>> {
         match self {
             Image::External(_) => None,
-            Image::Embedded(image) => Some(&mut image.image)
+            Image::Embedded(image) => Some(&mut image.image),
         }
     }
 }
 
 impl LayerKind {
-    pub fn is_physics_layer(&self) -> bool {
+    pub const fn is_physics_layer(&self) -> bool {
         use LayerKind::*;
         match self {
             Game | Front | Tele | Speedup | Switch | Tune => true,
@@ -147,7 +150,7 @@ impl LayerKind {
         }
     }
 
-    pub fn is_tile_map_layer(&self) -> bool {
+    pub const fn is_tile_map_layer(&self) -> bool {
         use LayerKind::*;
         match self {
             Game | Tiles | Front | Tele | Speedup | Switch | Tune => true,
@@ -160,7 +163,9 @@ impl<T> CompressedData<Array2<T>, TilesLoadInfo> {
     /// Returns the (height, width) 2-dimensional array of tiles.
     pub fn shape(&self) -> (usize, usize) {
         match self {
-            CompressedData::Compressed(_, _, info) => (info.height.try_to(), info.width.try_to::<usize>()),
+            CompressedData::Compressed(_, _, info) => {
+                (info.height.try_to(), info.width.try_to::<usize>())
+            }
             CompressedData::Loaded(array) => (array.nrows(), array.ncols()),
         }
     }
@@ -168,7 +173,7 @@ impl<T> CompressedData<Array2<T>, TilesLoadInfo> {
 
 impl Layer {
     /// Returns an identifier for the type of the layer.
-    pub fn kind(&self) -> LayerKind {
+    pub const fn kind(&self) -> LayerKind {
         use Layer::*;
         match self {
             Game(_) => LayerKind::Game,
@@ -208,10 +213,22 @@ impl Quad {
     pub fn new(width: i32, height: i32) -> Self {
         Quad {
             corners: [
-                Point { x: -(width / 2), y: -(height / 2) },
-                Point { x: width / 2, y: -(height / 2) },
-                Point { x: -(width / 2), y: height / 2 },
-                Point { x: width / 2, y: height / 2 },
+                Point {
+                    x: -(width / 2),
+                    y: -(height / 2),
+                },
+                Point {
+                    x: width / 2,
+                    y: -(height / 2),
+                },
+                Point {
+                    x: -(width / 2),
+                    y: height / 2,
+                },
+                Point {
+                    x: width / 2,
+                    y: height / 2,
+                },
             ],
             position: Point { x: 0, y: 0 },
             colors: <[Color; 4]>::default(),
@@ -224,7 +241,7 @@ impl Quad {
             position_env: None,
             position_env_offset: 0,
             color_env: None,
-            color_env_offset: 0
+            color_env_offset: 0,
         }
     }
 }
@@ -262,9 +279,11 @@ impl<T, U> From<T> for CompressedData<T, U> {
 
 impl<T, U> CompressedData<T, U> {
     /// Returns a reference to the inner loaded value. Panics if isn't loaded.
-    pub fn unwrap_ref(&self) -> &T {
+    pub const fn unwrap_ref(&self) -> &T {
         match self {
-            CompressedData::Compressed(_, _, _) => panic!("Data is still compressed, reference unwrap unsuccessful"),
+            CompressedData::Compressed(_, _, _) => {
+                panic!("Data is still compressed, reference unwrap unsuccessful")
+            }
             CompressedData::Loaded(data) => data,
         }
     }
@@ -272,7 +291,9 @@ impl<T, U> CompressedData<T, U> {
     /// Returns a mutable reference to the inner loaded value. Panics if isn't loaded.
     pub fn unwrap_mut(&mut self) -> &mut T {
         match self {
-            CompressedData::Compressed(_, _, _) => panic!("Data is still compressed, mut reference unwrap unsuccessful"),
+            CompressedData::Compressed(_, _, _) => {
+                panic!("Data is still compressed, mut reference unwrap unsuccessful")
+            }
             CompressedData::Loaded(data) => data,
         }
     }
@@ -280,7 +301,9 @@ impl<T, U> CompressedData<T, U> {
     /// Returns the inner loaded value. Panics if isn't loaded.
     pub fn unwrap(self) -> T {
         match self {
-            CompressedData::Compressed(_, _, _) => panic!("Data is still compressed, unwrap unsuccessful"),
+            CompressedData::Compressed(_, _, _) => {
+                panic!("Data is still compressed, unwrap unsuccessful")
+            }
             CompressedData::Loaded(data) => data,
         }
     }
@@ -288,7 +311,7 @@ impl<T, U> CompressedData<T, U> {
 
 impl Envelope {
     /// Returns a reference to the name of the envelope.
-    pub fn name(&self) -> &String {
+    pub const fn name(&self) -> &String {
         use Envelope::*;
         match self {
             Position(env) => &env.name,
@@ -298,7 +321,7 @@ impl Envelope {
     }
 
     /// Returns a mutable reference to the name of the envelope.
-    pub fn name_mut (&mut self) -> &mut String {
+    pub fn name_mut(&mut self) -> &mut String {
         use Envelope::*;
         match self {
             Position(env) => &mut env.name,
@@ -335,7 +358,10 @@ impl Default for Group {
 impl Group {
     /// Constructor for the physics group, make sure not to change any values apart from the layers
     pub fn physics() -> Self {
-        Group { name: String::from("Game"), ..Group::default()}
+        Group {
+            name: String::from("Game"),
+            ..Group::default()
+        }
     }
 }
 
@@ -350,7 +376,7 @@ impl TilesLayer {
             image: None,
             tiles: Array2::default(shape).into(),
             name: "".to_string(),
-            auto_mapper: AutoMapper::default()
+            auto_mapper: AutoMapper::default(),
         }
     }
 }
@@ -393,7 +419,7 @@ impl Layer {
 
 impl Tile {
     /// Constructor, required due to unused bytes which will be set to 0.
-    pub fn new(id: u8, flags: TileFlags) -> Self {
+    pub const fn new(id: u8, flags: TileFlags) -> Self {
         Tile {
             id,
             flags,
@@ -405,7 +431,7 @@ impl Tile {
 
 impl GameTile {
     /// Constructor, required due to unused bytes which will be set to 0.
-    pub fn new(id: u8, flags: TileFlags) -> Self {
+    pub const fn new(id: u8, flags: TileFlags) -> Self {
         GameTile {
             id,
             flags,
@@ -475,16 +501,6 @@ impl BezierDefault for I32Color {
     }
 }
 
-impl Default for Position {
-    fn default() -> Self {
-        Position {
-            x: 0,
-            y: 0,
-            rotation: 0
-        }
-    }
-}
-
 impl BezierDefault for Position {}
 
 impl BezierDefault for i32 {}
@@ -574,39 +590,71 @@ impl TileMapLayer for TuneLayer {
 }
 
 impl AnyTile for Tile {
-    fn id(&self) -> u8 { self.id }
+    fn id(&self) -> u8 {
+        self.id
+    }
 
-    fn flags(&self) -> Option<TileFlags> { Some(self.flags) }
+    fn flags(&self) -> Option<TileFlags> {
+        Some(self.flags)
+    }
+
+    fn supports_vanilla_compression() -> bool {
+        true
+    }
 }
 
 impl AnyTile for GameTile {
-    fn id(&self) -> u8 { self.id }
+    fn id(&self) -> u8 {
+        self.id
+    }
 
-    fn flags(&self) -> Option<TileFlags> { Some(self.flags) }
+    fn flags(&self) -> Option<TileFlags> {
+        Some(self.flags)
+    }
+
+    fn supports_vanilla_compression() -> bool {
+        true
+    }
 }
 
 impl AnyTile for Switch {
-    fn id(&self) -> u8 { self.id }
+    fn id(&self) -> u8 {
+        self.id
+    }
 
-    fn flags(&self) -> Option<TileFlags> { Some(self.flags) }
+    fn flags(&self) -> Option<TileFlags> {
+        Some(self.flags)
+    }
 }
 
 impl AnyTile for Tele {
-    fn id(&self) -> u8 { self.id }
+    fn id(&self) -> u8 {
+        self.id
+    }
 
-    fn flags(&self) -> Option<TileFlags> { None }
+    fn flags(&self) -> Option<TileFlags> {
+        None
+    }
 }
 
 impl AnyTile for Speedup {
-    fn id(&self) -> u8 { self.id }
+    fn id(&self) -> u8 {
+        self.id
+    }
 
-    fn flags(&self) -> Option<TileFlags> { None }
+    fn flags(&self) -> Option<TileFlags> {
+        None
+    }
 }
 
 impl AnyTile for Tune {
-    fn id(&self) -> u8 { self.id }
+    fn id(&self) -> u8 {
+        self.id
+    }
 
-    fn flags(&self) -> Option<TileFlags> { None }
+    fn flags(&self) -> Option<TileFlags> {
+        None
+    }
 }
 
 impl AnyLayer for GameLayer {
@@ -617,8 +665,7 @@ impl AnyLayer for GameLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Game(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -626,8 +673,7 @@ impl AnyLayer for GameLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Game(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -641,8 +687,7 @@ impl AnyLayer for TilesLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Tiles(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -650,8 +695,7 @@ impl AnyLayer for TilesLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Tiles(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -665,8 +709,7 @@ impl AnyLayer for QuadsLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Quads(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -674,8 +717,7 @@ impl AnyLayer for QuadsLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Quads(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -689,8 +731,7 @@ impl AnyLayer for FrontLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Front(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -698,8 +739,7 @@ impl AnyLayer for FrontLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Front(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -713,8 +753,7 @@ impl AnyLayer for TeleLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Tele(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -722,8 +761,7 @@ impl AnyLayer for TeleLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Tele(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -737,8 +775,7 @@ impl AnyLayer for SpeedupLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Speedup(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -746,8 +783,7 @@ impl AnyLayer for SpeedupLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Speedup(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -761,8 +797,7 @@ impl AnyLayer for SwitchLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Switch(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -770,8 +805,7 @@ impl AnyLayer for SwitchLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Switch(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -785,8 +819,7 @@ impl AnyLayer for TuneLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Tune(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -794,8 +827,7 @@ impl AnyLayer for TuneLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Tune(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -809,8 +841,7 @@ impl AnyLayer for SoundsLayer {
     fn get(layer: &Layer) -> Option<&Self> {
         if let Layer::Sounds(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
@@ -818,8 +849,7 @@ impl AnyLayer for SoundsLayer {
     fn get_mut(layer: &mut Layer) -> Option<&mut Self> {
         if let Layer::Sounds(l) = layer {
             Some(l)
-        }
-        else {
+        } else {
             None
         }
     }
