@@ -1,9 +1,9 @@
-use crate::map::*;
-use crate::map_parse::MapVersion;
-use crate::map_checks::bezier_in_use;
-use crate::datafile_parse::Item;
-use crate::datafile_save::{SaveError, save as save_datafile};
 use crate::convert::TryTo;
+use crate::datafile_parse::Item;
+use crate::datafile_save::{save as save_datafile, SaveError};
+use crate::map::*;
+use crate::map_checks::bezier_in_use;
+use crate::map_parse::MapVersion;
 
 use itertools::Itertools;
 use structview::View;
@@ -30,15 +30,15 @@ impl From<SaveError> for Error {
 impl ItemType {
     fn identifier(&self) -> Identifier {
         match self {
-            ItemType::Version     => Identifier::TypeId(0),
-            ItemType::Info        => Identifier::TypeId(1),
-            ItemType::Image       => Identifier::TypeId(2),
-            ItemType::Envelope    => Identifier::TypeId(3),
-            ItemType::Group       => Identifier::TypeId(4),
-            ItemType::Layer       => Identifier::TypeId(5),
-            ItemType::EnvPoints   => Identifier::TypeId(6),
-            ItemType::Sound       => Identifier::TypeId(7),
-            ItemType::AutoMapper  => Identifier::Uuid(AutoMapper::uuid()),
+            ItemType::Version => Identifier::TypeId(0),
+            ItemType::Info => Identifier::TypeId(1),
+            ItemType::Image => Identifier::TypeId(2),
+            ItemType::Envelope => Identifier::TypeId(3),
+            ItemType::Group => Identifier::TypeId(4),
+            ItemType::Layer => Identifier::TypeId(5),
+            ItemType::EnvPoints => Identifier::TypeId(6),
+            ItemType::Sound => Identifier::TypeId(7),
+            ItemType::AutoMapper => Identifier::Uuid(AutoMapper::uuid()),
             ItemType::Unknown(id) => panic!("type id not available for MapItem of id {}", id),
         }
     }
@@ -83,16 +83,21 @@ fn uuid_equal(u1: &[u8; 16], u2: &[i32; 4]) -> bool {
 }
 
 // initializes an ex item type by adding its uuid to the ex item index, returning the initialized type id
-fn add_uuid_type(items: &mut HashMap<u16, Vec<Item>>,uuid: [u8; 16]) -> u16 {
+fn add_uuid_type(items: &mut HashMap<u16, Vec<Item>>, uuid: [u8; 16]) -> u16 {
     let ex_item_id = 0xffff;
     match items.get(&ex_item_id) {
         // None => insert the ex items index
-        None => { items.insert(ex_item_id, Vec::new()); },
+        None => {
+            items.insert(ex_item_id, Vec::new());
+        }
         // Some => check if uuid was already inserted before
         Some(ex_items) => {
             for item in ex_items {
                 if uuid_equal(&uuid, item.item_data[..4].try_into().unwrap()) {
-                    panic!("Tried to insert ex_items of already inserted uuid: {:?}.", uuid);
+                    panic!(
+                        "Tried to insert ex_items of already inserted uuid: {:?}.",
+                        uuid
+                    );
                 }
             }
         }
@@ -101,7 +106,8 @@ fn add_uuid_type(items: &mut HashMap<u16, Vec<Item>>,uuid: [u8; 16]) -> u16 {
     let type_id = ex_item_id - ex_items.len().try_to::<u16>() - 1;
     let item = Item {
         id: type_id,
-        item_data: uuid.chunks(4)
+        item_data: uuid
+            .chunks(4)
             .map(|bytes| i32::from_be_bytes(bytes[0..4].try_into().unwrap()))
             .collect(),
     };
@@ -110,23 +116,34 @@ fn add_uuid_type(items: &mut HashMap<u16, Vec<Item>>,uuid: [u8; 16]) -> u16 {
 }
 
 // wrapper around insert, does nothing on None
-fn option_insert<'a>(items: &mut HashMap<u16, Vec<Item>>, data_items: &mut Vec<Cow<'a, [u8]>>, option_to_insert: Option<ItemTypeInsert<'a>>) {
+fn option_insert<'a>(
+    items: &mut HashMap<u16, Vec<Item>>,
+    data_items: &mut Vec<Cow<'a, [u8]>>,
+    option_to_insert: Option<ItemTypeInsert<'a>>,
+) {
     match option_to_insert {
         None => (),
-        Some(to_insert) => insert(items, data_items, to_insert)
+        Some(to_insert) => insert(items, data_items, to_insert),
     }
 }
 
 // add the data of a item type to the datafile, using a ItemTypeInsert
-fn insert<'a>(mut items: &mut HashMap<u16, Vec<Item>>, data_items: &mut Vec<Cow<'a, [u8]>>, mut to_insert: ItemTypeInsert<'a>) {
+fn insert<'a>(
+    items: &mut HashMap<u16, Vec<Item>>,
+    data_items: &mut Vec<Cow<'a, [u8]>>,
+    mut to_insert: ItemTypeInsert<'a>,
+) {
     assert_ne!(to_insert.items.len(), 0);
     let type_id = match to_insert.id {
         Identifier::TypeId(id) => id,
-        Identifier::Uuid(uuid) => add_uuid_type(&mut items, uuid),
+        Identifier::Uuid(uuid) => add_uuid_type(items, uuid),
     };
     let replaced = items.insert(type_id, to_insert.items);
     if replaced.is_some() {
-        panic!("Tried to insert items of already existing type id: {}", type_id);
+        panic!(
+            "Tried to insert items of already existing type id: {}",
+            type_id
+        );
     }
     data_items.append(&mut to_insert.data_items);
 }
@@ -154,7 +171,8 @@ impl TwMap {
     }
 
     // stitches the datafile together by continuously filling up items and data_items with all components of the map
-    pub(crate) fn save_to_datafile_unwrap(&self) -> (HashMap<u16, Vec<Item>>, Vec<Cow<[u8]>>){
+    #[allow(clippy::type_complexity)] // TODO: refactor return types into a type
+    pub(crate) fn save_to_datafile_unwrap(&self) -> (HashMap<u16, Vec<Item>>, Vec<Cow<[u8]>>) {
         let mut items = HashMap::new();
         let mut data_items = Vec::new();
 
@@ -243,29 +261,26 @@ impl Info {
                     string_data.extend(c_string(string))
                 }
                 data.push(Cow::from(string_data))
-            }
-            else {
+            } else {
                 item_data.push(-1);
             }
         }
-        let item = Item {
-            id: 0,
-            item_data,
-        };
+        let item = Item { id: 0, item_data };
         (item, data)
     }
 }
 
 impl Image {
     fn save(map_images: &[Image], version: Version, data_len: i32) -> Option<ItemTypeInsert> {
-        if map_images.len() == 0 {
+        if map_images.is_empty() {
             return None;
         }
         let mut items = Vec::new();
         let mut data_items = Vec::new();
         for (i, image) in map_images.iter().enumerate() {
             let id = i.try_to();
-            let (new_item, new_data_items) = image.itemize(id, version, data_len + data_items.len().try_to::<i32>());
+            let (new_item, new_data_items) =
+                image.itemize(id, version, data_len + data_items.len().try_to::<i32>());
             items.push(new_item);
             data_items.extend(new_data_items);
         }
@@ -291,7 +306,7 @@ impl Image {
             None => {
                 item_data[3] = true.into();
                 item_data[5] = -1;
-            },
+            }
             Some(CompressedData::Compressed(_, _, _)) => unreachable!(),
             Some(CompressedData::Loaded(image)) => {
                 item_data[3] = false.into();
@@ -302,31 +317,32 @@ impl Image {
         if version == Version::Teeworlds07 {
             item_data.push(1); // identifies image as rgba, support for rgb (0) is deprecated
         }
-        let item = Item {
-            id,
-            item_data
-        };
+        let item = Item { id, item_data };
         (item, data_items)
     }
 }
 
-
-fn string_to_i32s(str: &String, i32_count: usize) -> Vec<i32> {
-    assert!(str.len() + 1 <= i32_count * 4);
-    let mut bytes = str.clone().into_bytes()
-        .into_iter()
+fn string_to_i32s(str: &str, i32_count: usize) -> Vec<i32> {
+    assert!(str.len() < i32_count * 4);
+    let mut bytes = str
+        .bytes()
         .pad_using(i32_count * 4, |_| 0)
         .map(|x| x.wrapping_sub(128)) // still why
-        .collect::<Vec<u8>>();
+        .collect_vec();
     bytes[i32_count * 4 - 1] = 0; // set last byte to null
-    bytes.chunks(4)
-        .into_iter()
+    bytes
+        .chunks(4)
         .map(|i32_bytes| i32::from_be_bytes(i32_bytes.try_into().unwrap()))
-        .collect::<Vec<i32>>()
+        .collect_vec()
 }
 
 impl<T: EnvPointContentWriting + Copy> Env<T> {
-    fn itemize(&self, id: u16, total_points_len: i32, bezier_in_use: bool) -> (Item, Vec<i32>, i32) {
+    fn itemize(
+        &self,
+        id: u16,
+        total_points_len: i32,
+        bezier_in_use: bool,
+    ) -> (Item, Vec<i32>, i32) {
         let mut item_data = [0; 13];
 
         item_data[0] = match bezier_in_use {
@@ -337,7 +353,7 @@ impl<T: EnvPointContentWriting + Copy> Env<T> {
         item_data[2] = total_points_len; // index of first point
         item_data[3] = self.points.len().try_to::<i32>(); // number of points in envelope
         item_data[12] = self.synchronized.into(); // bo
-        let i32_string= string_to_i32s(&self.name, 8);
+        let i32_string = string_to_i32s(&self.name, 8);
         item_data[4..12].copy_from_slice(&i32_string);
         let point_data = match bezier_in_use {
             false => EnvPoint::<T>::vec_to_raw_v1(&self.points),
@@ -351,7 +367,7 @@ impl<T: EnvPointContentWriting + Copy> Env<T> {
     }
 }
 
-impl<T> CurveKind<T> {
+impl<T: Copy> CurveKind<T> {
     fn to_id(self) -> i32 {
         use CurveKind::*;
         match self {
@@ -361,7 +377,10 @@ impl<T> CurveKind<T> {
             Fast => 3,
             Smooth => 4,
             Bezier(_) => 5,
-            Unknown(n) => panic!("Tried to access i32 representation of unknown curve type {}", n),
+            Unknown(n) => panic!(
+                "Tried to access i32 representation of unknown curve type {}",
+                n
+            ),
         }
     }
 }
@@ -423,7 +442,7 @@ impl<T: EnvPointContentWriting> From<CurveKind<T>> for CurveKind<[i32; 4]> {
 }
 
 impl<T: EnvPointContentWriting + Copy> EnvPoint<T> {
-    fn to_raw_v1(&self) -> [i32; 6] {
+    fn to_raw_v1(self) -> [i32; 6] {
         let mut data = [0; 6];
         data[0] = self.time;
         data[1] = self.curve.to_id();
@@ -432,17 +451,14 @@ impl<T: EnvPointContentWriting + Copy> EnvPoint<T> {
         data
     }
 
-    fn to_raw_v2(&self) -> [i32; 22] {
+    fn to_raw_v2(self) -> [i32; 22] {
         let mut data = [0; 22];
         data[0..6].copy_from_slice(&self.to_raw_v1());
-        match CurveKind::<[i32; 4]>::from(self.curve) {
-            CurveKind::Bezier(b) => {
-                data[6..10].copy_from_slice(&b.in_tangent_dx);
-                data[10..14].copy_from_slice(&b.in_tangent_dy);
-                data[14..18].copy_from_slice(&b.out_tangent_dx);
-                data[18..22].copy_from_slice(&b.out_tangent_dy);
-            }
-            _ => {},
+        if let CurveKind::Bezier(b) = CurveKind::<[i32; 4]>::from(self.curve) {
+            data[6..10].copy_from_slice(&b.in_tangent_dx);
+            data[10..14].copy_from_slice(&b.in_tangent_dy);
+            data[14..18].copy_from_slice(&b.out_tangent_dx);
+            data[18..22].copy_from_slice(&b.out_tangent_dy);
         }
 
         data
@@ -479,7 +495,7 @@ impl Envelope {
             data_items: vec![],
         };
 
-        if map_envelopes.len() == 0 {
+        if map_envelopes.is_empty() {
             return (None, env_points_save);
         }
 
@@ -489,7 +505,8 @@ impl Envelope {
         let bezier_in_use = bezier_in_use(map_envelopes);
 
         for (i, envelope) in map_envelopes.iter().enumerate() {
-            let (new_item, new_env_point_data, new_env_point_count) = envelope.itemize(i.try_to(), total_points_len, bezier_in_use);
+            let (new_item, new_env_point_data, new_env_point_count) =
+                envelope.itemize(i.try_to(), total_points_len, bezier_in_use);
             envelope_items.push(new_item);
             env_point_data.extend(new_env_point_data);
             total_points_len += new_env_point_count;
@@ -502,11 +519,15 @@ impl Envelope {
 
         env_points_save.items[0].item_data = env_point_data;
 
-
         (Some(envelope_save), env_points_save)
     }
 
-    fn itemize(&self, id: u16, total_points_len: i32, bezier_in_use: bool) -> (Item, Vec<i32>, i32) {
+    fn itemize(
+        &self,
+        id: u16,
+        total_points_len: i32,
+        bezier_in_use: bool,
+    ) -> (Item, Vec<i32>, i32) {
         use Envelope::*;
         match self {
             Position(position_env) => position_env.itemize(id, total_points_len, bezier_in_use),
@@ -535,7 +556,7 @@ impl Group {
     }
 
     fn itemize(&self, first_layer_index: i32, id: u16) -> (Item, i32) {
-        let mut item_data = [0;15];
+        let mut item_data = [0; 15];
 
         item_data[0] = 3; // version
         item_data[1] = self.offset_x;
@@ -552,10 +573,7 @@ impl Group {
         item_data[12..15].copy_from_slice(&string_to_i32s(&self.name, 3));
 
         let item_data = item_data.to_vec();
-        (Item {
-            id,
-            item_data,
-        }, self.layers.len().try_to())
+        (Item { id, item_data }, self.layers.len().try_to())
     }
 }
 
@@ -570,9 +588,10 @@ trait ViewAsBytes: View {
     }
 }
 
-impl <T: View> ViewAsBytes for T {}
+impl<T: View> ViewAsBytes for T {}
 
-trait TileCompression: AnyTile { // only tiles of type 'Tile' and 'GameTile' can actually be compressed
+trait TileCompression: AnyTile {
+    // only tiles of type 'Tile' and 'GameTile' can actually be compressed
     fn compress_tiles(_: Vec<Self>) -> Vec<Self> {
         panic!();
     }
@@ -580,20 +599,18 @@ trait TileCompression: AnyTile { // only tiles of type 'Tile' and 'GameTile' can
 
 impl TileCompression for Tile {
     fn compress_tiles(tiles: Vec<Tile>) -> Vec<Tile> {
-        let mut compressed_tiles = Vec::new();
-        compressed_tiles.push(tiles[0]);
+        let mut compressed_tiles = vec![tiles[0]];
 
         for &tile in &tiles[1..] {
             let current_tile = compressed_tiles.last_mut().unwrap();
 
-            if current_tile.skip == u8::MAX { // maximum for tile skipping (255)
+            if current_tile.skip == u8::MAX {
+                // maximum for tile skipping (255)
                 compressed_tiles.push(tile);
+            } else if current_tile.id == tile.id && current_tile.flags == tile.flags {
+                current_tile.skip += 1;
             } else {
-                if current_tile.id == tile.id && current_tile.flags == tile.flags {
-                    current_tile.skip += 1;
-                } else {
-                    compressed_tiles.push(tile);
-                }
+                compressed_tiles.push(tile);
             }
         }
         compressed_tiles
@@ -602,20 +619,18 @@ impl TileCompression for Tile {
 
 impl TileCompression for GameTile {
     fn compress_tiles(tiles: Vec<GameTile>) -> Vec<GameTile> {
-        let mut compressed_tiles = Vec::new();
-        compressed_tiles.push(tiles[0]);
+        let mut compressed_tiles = vec![tiles[0]];
 
         for &tile in &tiles[1..] {
             let current_tile = compressed_tiles.last_mut().unwrap();
 
-            if current_tile.skip == u8::MAX { // maximum for tile skipping (255)
+            if current_tile.skip == u8::MAX {
+                // maximum for tile skipping (255)
                 compressed_tiles.push(tile);
+            } else if current_tile.id == tile.id && current_tile.flags == tile.flags {
+                current_tile.skip += 1;
             } else {
-                if current_tile.id == tile.id && current_tile.flags == tile.flags {
-                    current_tile.skip += 1;
-                } else {
-                    compressed_tiles.push(tile);
-                }
+                compressed_tiles.push(tile);
             }
         }
         compressed_tiles
@@ -631,7 +646,9 @@ impl TileCompression for Tune {}
 impl TileCompression for Speedup {}
 
 trait PhysicsLayerSaving: TileMapLayer
-    where Self::TileType: TileCompression {
+where
+    Self::TileType: TileCompression,
+{
     fn tiles_layer_flag() -> i32;
 
     fn itemize(&self, version: Version, data_len: i32, id: u16) -> (Item, Vec<Cow<[u8]>>) {
@@ -640,7 +657,8 @@ trait PhysicsLayerSaving: TileMapLayer
         item_data[0] = 0; // uninitialized value
         item_data[1] = 2; // layer type -> tile layer
         item_data[2] = 0; // flags, first bit: detail (not interesting for physics layers)
-        item_data[3] = match version { // write version
+        item_data[3] = match version {
+            // write version
             Version::DDNet06 => 3,
             Version::Teeworlds07 => 4,
         };
@@ -649,17 +667,24 @@ trait PhysicsLayerSaving: TileMapLayer
         let height = self.tiles().unwrap_ref().nrows();
         item_data[5] = height.try_to();
         item_data[6] = Self::tiles_layer_flag(); // specifies type of tile layer
-        item_data[7..11].copy_from_slice(&[255;4]); // color
+        item_data[7..11].copy_from_slice(&[255; 4]); // color
         item_data[11] = -1; // color env index
         item_data[12] = 0; // color env offset
         item_data[13] = -1; // image index
         item_data[14] = data_len;
-        item_data[15..18].copy_from_slice(&string_to_i32s(&String::from(Self::kind().static_name()), 3));
+        item_data[15..18].copy_from_slice(&string_to_i32s(
+            &String::from(Self::kind().static_name()),
+            3,
+        ));
         if version == Version::DDNet06 {
             item_data.extend(&[-1; 5]);
             if Self::kind() != LayerKind::Game {
                 item_data[Self::kind().data_index()] = data_len + 1;
-                data_items.push(Cow::from(iter::repeat(0).take(width * height * mem::size_of::< Tile>()).collect::<Vec<_>>()));
+                data_items.push(Cow::from(
+                    iter::repeat(0)
+                        .take(width * height * mem::size_of::<Tile>())
+                        .collect::<Vec<_>>(),
+                ));
             }
         }
         let mut tiles = self.tiles().unwrap_ref().to_owned().into_raw_vec();
@@ -668,44 +693,59 @@ trait PhysicsLayerSaving: TileMapLayer
             tiles = Self::TileType::compress_tiles(tiles);
         }
 
-        data_items.push(Cow::from(Self::TileType::into_boxed_bytes(tiles
-            .into_boxed_slice())
-            .into_vec()));
-        (Item {
-            id,
-            item_data: item_data.to_vec(),
-        }, data_items)
+        data_items.push(Cow::from(
+            Self::TileType::into_boxed_bytes(tiles.into_boxed_slice()).into_vec(),
+        ));
+        (
+            Item {
+                id,
+                item_data: item_data.to_vec(),
+            },
+            data_items,
+        )
     }
 }
 
 impl PhysicsLayerSaving for GameLayer {
-    fn tiles_layer_flag() -> i32 { 1 }
+    fn tiles_layer_flag() -> i32 {
+        1
+    }
 }
 
 impl PhysicsLayerSaving for FrontLayer {
-    fn tiles_layer_flag() -> i32 { 8 }
+    fn tiles_layer_flag() -> i32 {
+        8
+    }
 }
 
 impl PhysicsLayerSaving for TeleLayer {
-    fn tiles_layer_flag() -> i32 { 2 }
+    fn tiles_layer_flag() -> i32 {
+        2
+    }
 }
 
 impl PhysicsLayerSaving for SpeedupLayer {
-    fn tiles_layer_flag() -> i32 { 4 }
+    fn tiles_layer_flag() -> i32 {
+        4
+    }
 }
 
 impl PhysicsLayerSaving for SwitchLayer {
-    fn tiles_layer_flag() -> i32 { 16 }
+    fn tiles_layer_flag() -> i32 {
+        16
+    }
 }
 
 impl PhysicsLayerSaving for TuneLayer {
-    fn tiles_layer_flag() -> i32 { 32 }
+    fn tiles_layer_flag() -> i32 {
+        32
+    }
 }
 
 fn from_u16_option_index(index: Option<u16>) -> i32 {
     match index {
         None => -1,
-        Some(n) => n.into()
+        Some(n) => n.into(),
     }
 }
 
@@ -739,33 +779,31 @@ impl TilesLayer {
         if version == Version::Teeworlds07 {
             tiles = Tile::compress_tiles(tiles);
         }
-        data_items.push(Cow::from(Tile::into_boxed_bytes(tiles
-            .into_boxed_slice())
-            .into_vec()));
+        data_items.push(Cow::from(
+            Tile::into_boxed_bytes(tiles.into_boxed_slice()).into_vec(),
+        ));
         if version == Version::DDNet06 {
             item_data.extend(&[-1; 5]);
         }
-        (Item {
-            id,
-            item_data: item_data.to_vec(),
-        }, data_items)
+        (
+            Item {
+                id,
+                item_data: item_data.to_vec(),
+            },
+            data_items,
+        )
     }
 }
 
 impl Point {
-    fn to_i32(&self) -> Vec<i32> {
+    fn to_i32(self) -> Vec<i32> {
         vec![self.x, self.y]
     }
 }
 
 impl Color {
-    fn to_i32(&self) -> Vec<i32> {
-        vec![
-            self.r.into(),
-            self.g.into(),
-            self.b.into(),
-            self.a.into(),
-        ]
+    fn to_i32(self) -> Vec<i32> {
+        vec![self.r.into(), self.g.into(), self.b.into(), self.a.into()]
     }
 }
 
@@ -815,10 +853,13 @@ impl QuadsLayer {
         item_data[7..10].copy_from_slice(&string_to_i32s(&self.name, 3));
 
         let data_items = vec![self.create_data_item()];
-        (Item {
-            id,
-            item_data: item_data.to_vec()
-        }, data_items)
+        (
+            Item {
+                id,
+                item_data: item_data.to_vec(),
+            },
+            data_items,
+        )
     }
 }
 
@@ -875,10 +916,13 @@ impl SoundsLayer {
         item_data[6] = from_u16_option_index(self.sound);
         item_data[7..10].copy_from_slice(&string_to_i32s(&self.name, 3));
         let data_items = vec![self.create_data_item()];
-        (Item {
-            id,
-            item_data: item_data.to_vec(),
-        }, data_items)
+        (
+            Item {
+                id,
+                item_data: item_data.to_vec(),
+            },
+            data_items,
+        )
     }
 }
 
@@ -889,7 +933,11 @@ impl Layer {
 
         for group in groups {
             for layer in &group.layers {
-                let (new_item, new_data_items) = layer.itemize(items.len().try_to(), version, data_len + data_items.len().try_to::<i32>());
+                let (new_item, new_data_items) = layer.itemize(
+                    items.len().try_to(),
+                    version,
+                    data_len + data_items.len().try_to::<i32>(),
+                );
                 items.push(new_item);
                 data_items.extend(new_data_items);
             }
@@ -923,13 +971,14 @@ impl Layer {
 
 impl Sound {
     fn save(map_sounds: &[Sound], data_len: i32) -> Option<ItemTypeInsert> {
-        if map_sounds.len() == 0 {
+        if map_sounds.is_empty() {
             return None;
         }
         let mut items = Vec::new();
         let mut data_items = Vec::new();
         for (i, sound) in map_sounds.iter().enumerate() {
-            let (new_item, new_data_items) = sound.itemize(i.try_to(), data_len + data_items.len().try_to::<i32>());
+            let (new_item, new_data_items) =
+                sound.itemize(i.try_to(), data_len + data_items.len().try_to::<i32>());
             items.push(new_item);
             data_items.extend(new_data_items);
         }
@@ -955,10 +1004,7 @@ impl Sound {
                 data_items.push(Cow::from(data))
             }
         }
-        let item = Item {
-            id,
-            item_data
-        };
+        let item = Item { id, item_data };
         (item, data_items)
     }
 }
@@ -970,7 +1016,11 @@ impl AutoMapper {
         for (group_id, group) in groups.iter().enumerate() {
             for (layer_id, layer) in group.layers.iter().enumerate() {
                 if let Layer::Tiles(layer) = layer {
-                    items.push(layer.auto_mapper.itemize(items.len().try_to(), group_id.try_to(), layer_id.try_to()));
+                    items.push(layer.auto_mapper.itemize(
+                        items.len().try_to(),
+                        group_id.try_to(),
+                        layer_id.try_to(),
+                    ));
                 }
             }
         }
@@ -979,8 +1029,8 @@ impl AutoMapper {
             _ => Some(ItemTypeInsert {
                 id: ItemType::AutoMapper.identifier(),
                 items,
-                data_items: vec![]
-            })
+                data_items: vec![],
+            }),
         }
     }
     fn itemize(&self, id: u16, group_id: u16, layer_id: u16) -> Item {
