@@ -87,7 +87,8 @@ fn tile_flags_ddnet_test() {
 
 #[test]
 fn custom_test_ddnet() {
-    let tf: Vec<TileFlags> = (0..16).into_iter()
+    let tf: Vec<TileFlags> = (0..16)
+        .into_iter()
         .map(|n| TileFlags::from_bits(n).unwrap())
         .collect();
 
@@ -98,12 +99,18 @@ fn custom_test_ddnet() {
             version: String::new(),
             credits: String::from(""),
             license: String::new(),
-            settings: vec![String::from("Setting 1"), String::from("Unnecessary long setting abcdefghijklmnopqrstuvwxyz"), String::from("Setting 3")]
+            settings: vec![
+                String::from("Setting 1"),
+                String::from("Unnecessary long setting abcdefghijklmnopqrstuvwxyz"),
+                String::from("Setting 3"),
+            ],
         },
         images: vec![
             Image::Embedded(EmbeddedImage {
                 name: "name_with_128_bytes_length_restriction_image_1".to_string(),
-                image: RgbaImage::from_raw(16, 32, generate_data(32 * 16 * 4, 1, false)).unwrap().into(),
+                image: RgbaImage::from_raw(16, 32, generate_data(32 * 16 * 4, 1, false))
+                    .unwrap()
+                    .into(),
             }),
             Image::External(ExternalImage {
                 width: 1337,
@@ -112,7 +119,9 @@ fn custom_test_ddnet() {
             }),
             Image::Embedded(EmbeddedImage {
                 name: "".to_string(),
-                image: RgbaImage::from_raw(64, 32, generate_data(64 * 32 * 4, 2, true)).unwrap().into(),
+                image: RgbaImage::from_raw(64, 32, generate_data(64 * 32 * 4, 2, true))
+                    .unwrap()
+                    .into(),
             }),
         ],
         envelopes: vec![
@@ -121,32 +130,32 @@ fn custom_test_ddnet() {
                     EnvPoint {
                         time: 0,
                         curve: CurveKind::Step,
-                        content: 1
+                        content: 1,
                     },
                     EnvPoint {
                         time: 1,
                         curve: CurveKind::Fast,
-                        content: 2
-                    }
+                        content: 2,
+                    },
                 ],
                 name: "abcdefghijklmnopqrstuvwxyzabcde".to_string(),
-                synchronized: false
+                synchronized: false,
             }),
             Envelope::Sound(Env {
                 points: vec![
                     EnvPoint {
                         time: 0,
                         curve: CurveKind::Linear,
-                        content: 3
+                        content: 3,
                     },
                     EnvPoint {
                         time: i32::MAX,
                         curve: CurveKind::Slow,
-                        content: i32::MAX
-                    }
+                        content: i32::MAX,
+                    },
                 ],
                 name: "".to_string(),
-                synchronized: true
+                synchronized: true,
             }),
             Envelope::Position(Env {
                 points: vec![
@@ -167,26 +176,36 @@ fn custom_test_ddnet() {
                             y: i32::MAX,
                             rotation: i32::MAX,
                         },
-                    }
+                    },
                 ],
                 name: "abcdefghijklmnopqrstuvwxyzabcde".to_string(),
-                synchronized: false
+                synchronized: false,
             }),
             Envelope::Color(Env {
                 points: vec![
                     EnvPoint {
                         time: 0,
                         curve: CurveKind::Smooth,
-                        content: I32Color { r: 1, g: 2, b: 3, a: 4 }
+                        content: I32Color {
+                            r: 1,
+                            g: 2,
+                            b: 3,
+                            a: 4,
+                        },
                     },
                     EnvPoint {
                         time: i32::MAX,
                         curve: CurveKind::Linear,
-                        content: I32Color { r: i32::MAX, g: i32::MAX, b: i32::MAX, a: i32::MAX }
-                    }
+                        content: I32Color {
+                            r: i32::MAX,
+                            g: i32::MAX,
+                            b: i32::MAX,
+                            a: i32::MAX,
+                        },
+                    },
                 ],
                 name: "abcdefghijklmnopqrstuvwxyzabcde".to_string(),
-                synchronized: false
+                synchronized: false,
             }),
         ],
         groups: vec![
@@ -198,33 +217,55 @@ fn custom_test_ddnet() {
                 layers: vec![
                     Layer::Game(GameLayer {
                         tiles: CompressedData::Loaded(arr2(&[
-                            [GameTile::new(1, tf[0]), GameTile::new(2, tf[1]), GameTile::new(3, tf[2])],
-                            [GameTile::new(4, tf[3]), GameTile::new(5, tf[8]), GameTile::new(6, tf[9])],
-                        ]))
+                            [
+                                GameTile::new(1, tf[0]),
+                                GameTile::new(2, tf[1]),
+                                GameTile::new(3, tf[2]),
+                            ],
+                            [
+                                GameTile::new(4, tf[3]),
+                                GameTile::new(5, tf[8]),
+                                GameTile::new(6, tf[9]),
+                            ],
+                        ])),
                     }),
                     Layer::Tiles(TilesLayer {
                         detail: true,
-                        color: Color { r: 1, g: 2, b: 3, a: 4 },
+                        color: Color {
+                            r: 1,
+                            g: 2,
+                            b: 3,
+                            a: 4,
+                        },
                         color_env: Some(3),
                         color_env_offset: 21,
                         image: Some(2),
                         tiles: CompressedData::Loaded(arr2(&[
-                            [Tile::new(1, tf[6]), Tile::new(2, tf[7]) , Tile::new(3, tf[8]) ],
-                            [Tile::new(4, tf[9]), Tile::new(5, tf[10]), Tile::new(6, tf[11])],
+                            [
+                                Tile::new(1, tf[6]),
+                                Tile::new(2, tf[7]),
+                                Tile::new(3, tf[8]),
+                            ],
+                            [
+                                Tile::new(4, tf[9]),
+                                Tile::new(5, tf[10]),
+                                Tile::new(6, tf[11]),
+                            ],
                         ])),
                         name: "abcdefghijk".to_string(),
                         auto_mapper: AutoMapper {
                             config: None,
                             seed: 21,
-                            automatic: false
+                            automatic: false,
                         },
-                    })],
+                    }),
+                ],
                 clipping: false,
                 clip_x: 0,
                 clip_y: 0,
                 clip_width: 0,
                 clip_height: 0,
-                name: "Game".to_string()
+                name: "Game".to_string(),
             },
             Group {
                 offset_x: 1,
@@ -236,7 +277,7 @@ fn custom_test_ddnet() {
                         detail: false,
                         sources: vec![
                             SoundSource {
-                                position: Point { x: 21, y: 42},
+                                position: Point { x: 21, y: 42 },
                                 looping: true,
                                 panning: false,
                                 delay: 21,
@@ -245,10 +286,10 @@ fn custom_test_ddnet() {
                                 position_env_offset: 3,
                                 sound_env: Some(0),
                                 sound_env_offset: 7,
-                                shape: SoundShape::Circle { radius: 37 }
+                                shape: SoundShape::Circle { radius: 37 },
                             },
                             SoundSource {
-                                position: Point { x: 43, y: 68},
+                                position: Point { x: 43, y: 68 },
                                 looping: false,
                                 panning: true,
                                 delay: 42,
@@ -257,54 +298,103 @@ fn custom_test_ddnet() {
                                 position_env_offset: 0,
                                 sound_env: Some(1),
                                 sound_env_offset: 14,
-                                shape: SoundShape::Rectangle { width: 12, height: 34 }
-                            }
+                                shape: SoundShape::Rectangle {
+                                    width: 12,
+                                    height: 34,
+                                },
+                            },
                         ],
                         sound: None,
-                        name: "".to_string()
+                        name: "".to_string(),
                     }),
                     Layer::Quads(QuadsLayer {
-                                             detail: true,
-                                             quads: vec![
-                                                 Quad {
-                                                     position: Point { x: 12, y: 24 },
-                                                     corners: [Point { x: 1, y: 2 }, Point { x: 3, y: 4 }, Point { x: 5, y: 6 }, Point { x: 7, y: 8 }],
-                                                     colors: [Color { r: 9, g: 10, b: 11, a: 12 }, Color { r: 13, g: 14, b: 15, a: 16 }, Color { r: 17, g: 18, b: 19, a: 20 }, Color { r: 21, g: 22, b: 23, a: 24 }],
-                                                     texture_coords: [Point { x: 25, y: 26 }, Point { x: 27, y: 28 }, Point { x: 29, y: 30 }, Point { x: 31, y: 32 }],
-                                                     position_env: Some(2),
-                                                     position_env_offset: 33,
-                                                     color_env: Some(3),
-                                                     color_env_offset: 34
-                                                 }
-                                             ],
-                                             image: Some(1),
-                                             name: "another3i32".to_string()
-                                         }),
+                        detail: true,
+                        quads: vec![Quad {
+                            position: Point { x: 12, y: 24 },
+                            corners: [
+                                Point { x: 1, y: 2 },
+                                Point { x: 3, y: 4 },
+                                Point { x: 5, y: 6 },
+                                Point { x: 7, y: 8 },
+                            ],
+                            colors: [
+                                Color {
+                                    r: 9,
+                                    g: 10,
+                                    b: 11,
+                                    a: 12,
+                                },
+                                Color {
+                                    r: 13,
+                                    g: 14,
+                                    b: 15,
+                                    a: 16,
+                                },
+                                Color {
+                                    r: 17,
+                                    g: 18,
+                                    b: 19,
+                                    a: 20,
+                                },
+                                Color {
+                                    r: 21,
+                                    g: 22,
+                                    b: 23,
+                                    a: 24,
+                                },
+                            ],
+                            texture_coords: [
+                                Point { x: 25, y: 26 },
+                                Point { x: 27, y: 28 },
+                                Point { x: 29, y: 30 },
+                                Point { x: 31, y: 32 },
+                            ],
+                            position_env: Some(2),
+                            position_env_offset: 33,
+                            color_env: Some(3),
+                            color_env_offset: 34,
+                        }],
+                        image: Some(1),
+                        name: "another3i32".to_string(),
+                    }),
                     Layer::Tiles(TilesLayer {
-                                             detail: true,
-                                             color: Color { r: 21, g: 42, b: 63, a: 84 },
-                                             color_env: Some(3),
-                                             color_env_offset: 13,
-                                             image: Some(0),
-                                             tiles: CompressedData::Loaded(arr2(&[
-                                                 [Tile::new(11, tf[12]), Tile::new(13, tf[13]), Tile::new(15, tf[14])],
-                                                 [Tile::new(17, tf[15]), Tile::new(19, tf[14]), Tile::new(21, tf[13])],
-                                             ])),
-                                             name: "ABCDEFGHIJK".to_string(),
-                                             auto_mapper: AutoMapper {
-                                                 config: Some(1),
-                                                 seed: 2121,
-                                                 automatic: true
-                                             }
-                                         })
+                        detail: true,
+                        color: Color {
+                            r: 21,
+                            g: 42,
+                            b: 63,
+                            a: 84,
+                        },
+                        color_env: Some(3),
+                        color_env_offset: 13,
+                        image: Some(0),
+                        tiles: CompressedData::Loaded(arr2(&[
+                            [
+                                Tile::new(11, tf[12]),
+                                Tile::new(13, tf[13]),
+                                Tile::new(15, tf[14]),
+                            ],
+                            [
+                                Tile::new(17, tf[15]),
+                                Tile::new(19, tf[14]),
+                                Tile::new(21, tf[13]),
+                            ],
+                        ])),
+                        name: "ABCDEFGHIJK".to_string(),
+                        auto_mapper: AutoMapper {
+                            config: Some(1),
+                            seed: 2121,
+                            automatic: true,
+                        },
+                    }),
                 ],
                 clipping: true,
                 clip_x: 5,
                 clip_y: 6,
                 clip_width: 7,
                 clip_height: 8,
-                name: "3intsstring".to_string()
-            }
+                name: "3intsstring".to_string(),
+            },
         ],
         sounds: vec![],
     };
@@ -316,7 +406,8 @@ fn custom_test_ddnet() {
 
 #[test]
 fn custom_test_teeworlds07() {
-    let tf: Vec<TileFlags> = (0..16).into_iter()
+    let tf: Vec<TileFlags> = (0..16)
+        .into_iter()
         .map(|n| TileFlags::from_bits(n).unwrap())
         .collect();
 
@@ -328,98 +419,102 @@ fn custom_test_teeworlds07() {
             Envelope::Color(Env {
                 name: "Vanilla envelope".to_string(),
                 synchronized: false,
-                points: vec![
-                    EnvPoint {
-                        time: 0,
-                        curve: CurveKind::Bezier(BezierCurve {
-                            in_tangent_dx: I32Color {
-                                r: 0,
-                                g: 1,
-                                b: 2,
-                                a: 3
-                            },
-                            in_tangent_dy: I32Color {
-                                r: 4,
-                                g: 5,
-                                b: 6,
-                                a: 7,
-                            },
-                            out_tangent_dx: I32Color {
-                                r: 8,
-                                g: 9,
-                                b: 10,
-                                a: 11
-                            },
-                            out_tangent_dy: I32Color {
-                                r: 12,
-                                g: 13,
-                                b: 14,
-                                a: 15
-                            }
-                        }),
-                        content: I32Color {
+                points: vec![EnvPoint {
+                    time: 0,
+                    curve: CurveKind::Bezier(BezierCurve {
+                        in_tangent_dx: I32Color {
                             r: 0,
-                            g: 7,
+                            g: 1,
+                            b: 2,
+                            a: 3,
+                        },
+                        in_tangent_dy: I32Color {
+                            r: 4,
+                            g: 5,
+                            b: 6,
+                            a: 7,
+                        },
+                        out_tangent_dx: I32Color {
+                            r: 8,
+                            g: 9,
+                            b: 10,
+                            a: 11,
+                        },
+                        out_tangent_dy: I32Color {
+                            r: 12,
+                            g: 13,
                             b: 14,
-                            a: 21,
-                        }
-                    }],
+                            a: 15,
+                        },
+                    }),
+                    content: I32Color {
+                        r: 0,
+                        g: 7,
+                        b: 14,
+                        a: 21,
+                    },
+                }],
             }),
             Envelope::Position(Env {
                 name: "".to_string(),
                 synchronized: true,
-                points: vec![
-                    EnvPoint {
-                        time: 1,
-                        content: Position {
-                            x: 123,
-                            y: 456,
-                            rotation: 789,
+                points: vec![EnvPoint {
+                    time: 1,
+                    content: Position {
+                        x: 123,
+                        y: 456,
+                        rotation: 789,
+                    },
+                    curve: CurveKind::Bezier(BezierCurve {
+                        in_tangent_dx: Position {
+                            x: 16,
+                            y: 17,
+                            rotation: 18,
                         },
-                        curve: CurveKind::Bezier(BezierCurve {
-                            in_tangent_dx: Position {
-                                x: 16,
-                                y: 17,
-                                rotation: 18,
-                            },
-                            in_tangent_dy: Position {
-                                x: 19,
-                                y: 20,
-                                rotation: 21,
-                            },
-                            out_tangent_dx: Position {
-                                x: 22,
-                                y: 23,
-                                rotation: 24,
-                            },
-                            out_tangent_dy: Position {
-                                x: 25,
-                                y: 26,
-                                rotation: 27,
-                            }
-                        })
-                    }
-                ]
-            })
+                        in_tangent_dy: Position {
+                            x: 19,
+                            y: 20,
+                            rotation: 21,
+                        },
+                        out_tangent_dx: Position {
+                            x: 22,
+                            y: 23,
+                            rotation: 24,
+                        },
+                        out_tangent_dy: Position {
+                            x: 25,
+                            y: 26,
+                            rotation: 27,
+                        },
+                    }),
+                }],
+            }),
         ],
         groups: vec![Group {
             offset_x: 0,
             offset_y: 0,
             parallax_x: 100,
             parallax_y: 100,
-            layers: vec![
-                Layer::Game(GameLayer {
-                    tiles: CompressedData::Loaded(arr2(&[
-                        [GameTile::new(1, tf[0]), GameTile::new(2, tf[1]), GameTile::new(3, tf[2])],
-                        [GameTile::new(4, tf[3]), GameTile::new(5, tf[8]), GameTile::new(6, tf[9])],
-                    ]))
-                    })],
+            layers: vec![Layer::Game(GameLayer {
+                tiles: CompressedData::Loaded(arr2(&[
+                    [
+                        GameTile::new(1, tf[0]),
+                        GameTile::new(2, tf[1]),
+                        GameTile::new(3, tf[2]),
+                    ],
+                    [
+                        GameTile::new(4, tf[3]),
+                        GameTile::new(5, tf[8]),
+                        GameTile::new(6, tf[9]),
+                    ],
+                ])),
+            })],
             clipping: false,
             clip_x: 0,
             clip_y: 0,
             clip_width: 0,
             clip_height: 0,
-            name: "Game".to_string()
+            name: "Game".to_string(),
         }],
         sounds: vec![],
     };
